@@ -20,7 +20,7 @@ use YAML::Tiny;
 
 use vars qw($VERSION);
 
-$VERSION = '0.28';
+$VERSION = '0.30';
 
 use constant DATABASE_FILE => 'cpansmoke.dat';
 use constant CONFIG_FILE   => 'cpansmoke.ini';
@@ -106,6 +106,9 @@ my %throw_away;
 		  if ( $ENV{PERL5_MINIYACSMOKER} ) {
 			$report .= "Powered by miniyacsmoker version " . $ENV{PERL5_MINIYACSMOKER} . "\n";
 		  }
+		  if ( $ENV{PERL5_MINISMOKEBOX} ) {
+			$report .= "Powered by minismokebox version " . $ENV{PERL5_MINISMOKEBOX} . "\n";
+		  }
 		  $report .= _gen_report();
 		  return $report;
         },
